@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -50,6 +50,10 @@ $Verbose = $ENV{ALIEN_VERBOSE} if defined $ENV{ALIEN_VERBOSE};
 
 our $Force;
 $Force = $ENV{ALIEN_FORCE} if defined $ENV{ALIEN_FORCE};
+$Force = 1 if defined $ENV{ALIEN_INSTALL_TYPE} && $ENV{ALIEN_INSTALL_TYPE} eq 'share';
+
+our $ForceSystem;
+$ForceSystem = 1 if defined $ENV{ALIEN_INSTALL_TYPE} && $ENV{ALIEN_INSTALL_TYPE} eq 'system';
 
 ################
 #  Parameters  #
@@ -95,7 +99,7 @@ __PACKAGE__->add_property(
 );
 
 # alien_version_check: command to execute to check if install/version
-__PACKAGE__->add_property( alien_version_check => Alien::Base::PkgConfig->pkg_config_command . ' --modversion %n' );
+__PACKAGE__->add_property( alien_version_check => '%{pkg_config} --modversion %n' );
 
 # pkgconfig-esque info, author provides these by hand for now, will parse .pc file eventually
 __PACKAGE__->add_property( 'alien_provides_cflags' );
@@ -343,6 +347,10 @@ sub ACTION_alien_code {
     $self->config_data( system_provides => \%system_provides );
     return;
   }
+  
+  if ($ForceSystem) {
+    die "Requested system install, but system package not detected."
+  }
 
   my @repos = $self->alien_create_repositories;
 
@@ -1152,7 +1160,7 @@ In your Build.PL:
 
  use Alien::Base::ModuleBuild;
  
- my $builder = Alien::Base::Module::Build->new(
+ my $builder = Alien::Base::ModuleBuild->new(
    module_name => 'Alien::MyLibrary',
    
    configure_requires => {
